@@ -395,7 +395,7 @@ class ZMSMetaobjManager:
         ob = self.__get_metaobj__( id)
         if type( ob) is dict and (ob.get('type') == 'ZMSDocument' or ob.get('id') == 'ZMSTeaserContainer'):
           ids = map( lambda x: x['id'], filter( lambda x: x['type']=='*', ob['attrs']))
-          rtnVal = ids == ['e']
+          rtnVal = 'e' in ids
         
         #-- [ReqBuff]: Returns value and stores it in buffer of Http-Request.
         return self.storeReqBuff( reqBuffId, rtnVal, self.REQUEST)
@@ -582,6 +582,40 @@ class ZMSMetaobjManager:
       return attrs
 
 
+    # --------------------------------------------------------------------------
+    #  ZMSMetaobjManager.evalMetaobjAttr
+    # --------------------------------------------------------------------------
+    def evalMetaobjAttr(self, id, attr_id, zmscontext=None, options={}):
+      def call(fn):
+        if options:
+          return fn(zmscontext=zmscontext,options=options)
+        else:
+          return fn(zmscontext=zmscontext)
+      value = None
+      metaObjAttr = self.getMetaobjAttr( id, attr_id, syncTypes=['*'])
+      if metaObjAttr is not None:
+        if metaObjAttr['type'] == 'interface':
+          if metaObjAttr.get('py') is not None:
+            value = call(metaObjAttr['py'])
+          elif metaObjAttr.get('zpt') is not None:
+            value = call(metaObjAttr['zpt'])
+            value = unicode(value).encode('utf-8')
+          else:
+            value = zmscontext.dt_exec(metaObjAttr.get('name',''))
+        elif metaObjAttr['type'] == 'method':
+          value = zmscontext.dt_exec(metaObjAttr.get('custom',''))
+        elif metaObjAttr['type'] == 'py':
+          value = call(metaObjAttr['py'])
+        elif metaObjAttr['type'] == 'zpt':
+          value = call(metaObjAttr['zpt'])
+          value = unicode(value).encode('utf-8')
+        elif metaObjAttr['type'] == 'constant':
+          value = metaObjAttr.get('custom','')
+        elif metaObjAttr['type'] == 'resource':
+          value = metaObjAttr.get('custom',None)
+      return value
+
+
     # --------------------------------------------------------------------------
     #  ZMSMetaobjManager.getMetaobjAttr:
     # 
@@ -684,9 +718,7 @@ class ZMSMetaobjManager:
           newCustom += 'RESPONSE =  request.RESPONSE\n'
           newCustom += '\n'
           newCustom += '# Return a string identifying this script.\n'
-          newCustom += 'print "This is the", script.meta_type, \'"%s"\' % script.getId(),\n'
-          newCustom += 'if script.title:\n'
-          newCustom += '    print "(%s)" % html_quote(script.title),\n'
+          newCustom += 'print "This is the Python Script %s" % script.getId(),\n'
           newCustom += 'print "in", container.absolute_url()\n'
           newCustom += 'return printed\n'
           newCustom += '\n'
@@ -710,7 +742,8 @@ class ZMSMetaobjManager:
           self.manage_addFile( id=id+'.'+newId, file=newCustom.getData(),title=newCustom.getFilename(),content_type=newCustom.getContentType())
         elif oldId is not None and oldId != newId and id+'.'+oldId in self.objectIds():
           self.manage_renameObject(id=id+'.'+oldId,new_id=id+'.'+newId)
-        newCustom = ''
+        if not ob['type'] == 'ZMSRecordSet':
+          newCustom = ''
       
       attr = {}
       attr['sync'] = False
