@@ -172,6 +172,33 @@ class ZMSObject(ZMSItem.ZMSItem,
               l.append('/* >>>>>>>>>> ERROR in %s <<<<<<<<<< */'%_globals.writeError(self,"[zmi_css_defaults]: %s"%s))
       return '\n'.join(map(lambda x:str(x),l))
 
+    ############################################################################
+    #
+    # ZMS Object Index
+    #
+    ############################################################################
+
+    # --------------------------------------------------------------------------
+    #  ZMSObject.get_oid:
+    # --------------------------------------------------------------------------
+    def get_oid(self):
+      try:
+        from Shared.DC.xml.ppml import u64 as decodeObjectId
+      except:
+        from ZODB.utils import u64 as decodeObjectId
+      oid = None
+      if self._p_oid is not None:
+        oid = decodeObjectId(self._p_oid)
+      return oid
+
+    # --------------------------------------------------------------------------
+    #  ZMSObject.find_oid:
+    # --------------------------------------------------------------------------
+    def find_oid(self, oid):
+      from ZODB.utils import p64
+      ob = self._p_jar[p64(oid)]
+      return ob
+
 
     # --------------------------------------------------------------------------
     #  ZMSObject.title:
@@ -272,7 +299,7 @@ class ZMSObject(ZMSItem.ZMSItem,
     # --------------------------------------------------------------------------
     def getTitle( self, REQUEST):
       s = self.getObjProperty('title',REQUEST)
-      if len(s) == 0:
+      if s is None or len(s) == 0:
         if self.isPage():
           metaObjAttrs = self.getMetaobj( self.meta_id).get( 'attrs', [])
           offs = 1
@@ -285,13 +312,13 @@ class ZMSObject(ZMSItem.ZMSItem,
                   s = v
                   break
               c = c + 1
-      if len(s) == 0:
+      if s is None or len(s) == 0:
         s = self.display_type(REQUEST)
       if self.isPage():
         sec_no = self.getSecNo()
         if len(sec_no) > 0:
           s = sec_no + ' ' + s
-	  s = s.replace(' & ',' &amp; ')
+      s = s.replace(' & ',' &amp; ')
       return s
 
 
@@ -300,9 +327,9 @@ class ZMSObject(ZMSItem.ZMSItem,
     # --------------------------------------------------------------------------
     def getTitlealt( self, REQUEST):
       s = self.getObjProperty('titlealt',REQUEST)
-      if len(s) == 0: 
+      if s is None or len(s) == 0: 
         s = self.display_type(REQUEST)
-      if len(s) == 0:
+      if s is None or len(s) == 0:
         if self.isPage():
           metaObjAttrs = self.getMetaobj( self.meta_id).get( 'attrs', [])
           offs = 0
@@ -506,25 +533,12 @@ class ZMSObject(ZMSItem.ZMSItem,
         obj_type = self.meta_id
       if obj_type in self.getMetaobjIds( sort=0):
         if zpt:
-          metaObjAttr = self.getMetaobjAttr( obj_type, 'icon_clazz')
-          if metaObjAttr is not None:
-            icon_clazz = None
-            if metaObjAttr['type'] == 'py':
-              icon_clazz = metaObjAttr['py'](zmscontext=self)
-            elif metaObjAttr['type'] == 'constant':
-              icon_clazz = metaObjAttr.get('custom',None)
-            if icon_clazz:
-              return self.zmi_icon(self,name=icon_clazz,extra='title="%s"'%unicode(icon_title,'utf-8'))
-        if key in self.getMetaobjAttrIds( obj_type):
-          metaObjAttr = self.getMetaobjAttr( obj_type, key)
-          if metaObjAttr is not None and metaObjAttr['type'] == 'method':
-            value = self.dt_html(metaObjAttr.get('custom',''))
-          elif metaObjAttr is not None and metaObjAttr['type'] == 'py':
-            value = metaObjAttr['py'](zmscontext=self)
-          else:
-            value = metaObjAttr.get( 'custom', None)
-          if value is not None and type(value) is not str:
-            return pattern%value.absolute_url()
+          icon_clazz = self.evalMetaobjAttr( '%s.%s'%(obj_type,'icon_clazz'))
+          if icon_clazz is not None:
+            return self.zmi_icon(self,name=icon_clazz,extra='title="%s"'%unicode(icon_title,'utf-8'))
+        value = self.evalMetaobjAttr( '%s.%s'%(obj_type,key)) 
+        if value is not None and type(value) is not str:
+          return pattern%value.absolute_url()
         metaObj = self.getMetaobj( obj_type)
         if metaObj:
           if metaObj[ 'type'] == 'ZMSResource':
@@ -1019,6 +1033,7 @@ class ZMSObject(ZMSItem.ZMSItem,
       xml += " title=\"%s\""%_globals.html_quote(self.getTitle(REQUEST))
       xml += " titlealt=\"%s\""%_globals.html_quote(self.getTitlealt(REQUEST))
       xml += " restricted=\"%s\""%str(self.hasRestrictedAccess())
+      xml += " attr_dc_type=\"%s\""%(self.attr('attr_dc_type'))
       xml += ">"
       if REQUEST.form.get('get_attrs', 1):
         obj_attrs = self.getObjAttrs()
@@ -1253,7 +1268,7 @@ class ZMSObject(ZMSItem.ZMSItem,
       if _globals.isPreviewRequest(request) and \
          (request.get('URL').find('/manage')>0 or self.getConfProperty('ZMS.preview.contentEditable',1)==1):
         ids = ['contentEditable',self.id,request['lang']]
-        css = ['contentEditable']
+        css = ['contentEditable', self.meta_id]
         html = '<div class="%s" id="%s">%s</div>'%(' '.join(css),'_'.join(ids),html)
       return html
 
